Re: [PATCH] builtin/mv.c: use correct type to compute size of an array element
- From
Junio C Hamano <gitster@pobox.com>
- Date
- Jul 10, 2022, 05:38 UTC
- Message-ID
- <xmqqmtdhsf1z.fsf@gitster.g>
- In-Reply-To
- <95432eb4-e66a-5c04-9267-f71391fbe277@web.de>
René Scharfe <l.s.r@web.de> writes:
> Not a problem, it seems; at least Coccinelle 1.1.1 is still able to > recreate the conversions from 45ccef87b3 (use COPY_ARRAY, 2016-09-25) > and 921d49be86 (use COPY_ARRAY for copying arrays, 2019-06-15) with the > patch below, which removes the normalization rules.
The result certainly is cleaner and also looks much less error prone.
> It increases the > processing time for array.cocci from 53s to 66s for me, though. Worth > the increased precision and clarity?
I would say so. For manual tests that humans stare at their progress waiting for their completion, every second may matter, but a check that makes us wait for more than 30 seconds *and* forces us to be extra careful when vetting its validity is worse than a check that takes 10 more seconds with much less risk of broken output.